@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "torrent-mode" "0.2.2"
+(define-package "torrent-mode" "20250813.1529"
   "Display torrent files in a tabulated view."
   '((emacs     "26.1")
     (tablist   "1.0")
     (bencoding "1.0"))
   :url "https://github.com/sarg/torrent-mode.el"
-  :commit "a35a7c193b638207de0a266e8ded6e4e8a54505e"
-  :revdesc "a35a7c193b63"
+  :commit "5dbb59c60c0c2db24d3d138eb003c66c3578b7b4"
+  :revdesc "5dbb59c60c0c"
   :authors '(("Sergey Trofimov" . "sarg@sarg.org.ru"))
   :maintainers '(("Sergey Trofimov" . "sarg@sarg.org.ru")))
